##  Basic Settings
The Basic Settings category in the administration area includes sections listed in the following table.
Section | Description | Related Information
---|---|---
Branding | Customize the look and feel of the workspace to match your brand identity. |  [Branding Settings](https://help.sap.com/docs/leanix/ea/branding-settings?locale=en-US&state=PRODUCTION&version=CLOUD "Personalize your workspace's appearance to reflect your brand identity or choose from one of the predefined workspace designs.")
General | Configure basic workspace settings. |  [General Settings](https://help.sap.com/docs/leanix/ea/general-settings?locale=en-US&state=PRODUCTION&version=CLOUD "General Settings encompass fundamental configurations that align workspace functionality, user preferences, and security with organizational requirements.")
Meta Model Configuration | Configure the meta model to adjust it to your organization's requirements. |  [Meta Model Configuration](https://help.sap.com/docs/leanix/ea/meta-model-configuration?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the meta model to adjust it to your requirements.")
Subscription Roles | Create subscription roles to define responsibility and accountability in relation to fact sheets that match your organizational structure. |  [Subscription Roles](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to create, edit, and delete subscription roles and manage settings like enabling the 'Accountable' type, limiting multiple subscriptions, and enforcing mandatory role selection.")
Tagging | Create tags that can be added to fact sheets to enhance data categorization and searchability. |  [Tagging](https://help.sap.com/docs/leanix/ea/tagging?locale=en-US&state=PRODUCTION&version=CLOUD "This guide covers the essential steps for managing tags, including creating tag groups, adding and editing tags within those groups, and deleting tags and tag groups. Suggest Edits Introduction")
Users | Get an overview of users who have access to the workspace or were invited to it and manage user access permissions and roles. |  [Users Overview](https://help.sap.com/docs/leanix/ea/users-overview?locale=en-US&state=PRODUCTION&version=CLOUD "View workspace users and manage their access permissions and roles.")
User Roles and Permissions | Configure custom user roles (if you're managing user roles within your single sign-on identity provider) and manage role-based permissions. |  [User Roles and Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust role-based permissions and define custom roles.")
Dashboards | Configure dashboard settings and add specific dashboards to the workspace. |  [Dashboards Settings](https://help.sap.com/docs/leanix/ea/dashboards-settings?locale=en-US&state=PRODUCTION&version=CLOUD "Configure dashboard settings and add specific dashboards to the workspace.")


